.. note::
    place names and roles of the people who contribute to this package
    in this file, one to a line, like so:

- Timo Stollenwerk, Original Author
- Thomas Buchberger
- Lukas Graf
- Víctor Fernández de Alba
- Paul Roeland
- Mikel Larreategi
- Eric Brehault
- Andreas Zeidler
- Carsten Senger
- Tom Gross
- Roel Bruggink
- Yann Fouillat, alias Gagaro
- Sune Brøndum Wøller
- Philippe Gross
- Andrea Cecchi
- Luca Bellenghi
- Giacomo Monari
- Alin Voinea
- Rodrigo Ferreira de Souza
- Jens W. Klein
- Maurits van Rees
- Gil Forcada Codinachs
- David Glick
- Philip Bauer
- Tiberiu Ichim
- Érico Andrei
- Jonas Baumann
- Cédric Messiant
- Héctor Velarde
- Johannes Raggam
- Simone Deponti
- Wesley Barroso Lopes
- Elio Schmutz
- Gauthier Bastien
- Katja Süss
  